grib2io.tables.section4_discipline0 API documentation

# grib2io.tables.section4_discipline0

View Source

    table_4_2_0_0  = {
    '0':['Temperature','K','TMP'],
    '1':['Virtual Temperature','K','VTMP'],
    '2':['Potential Temperature','K','POT'],
    '3':['Pseudo-Adiabatic Potential Temperature (or Equivalent Potential Temperature)','K','EPOT'],
    '4':['Maximum Temperature*','K','TMAX'],
    '5':['Minimum Temperature*','K','TMIN'],
    '6':['Dew Point Temperature','K','DPT'],
    '7':['Dew Point Depression (or Deficit)','K','DEPR'],
    '8':['Lapse Rate','K m-1','LAPR'],
    '9':['Temperature Anomaly','K','TMPA'],
    '10':['Latent Heat Net Flux','W m-2','LHTFL'],
    '11':['Sensible Heat Net Flux','W m-2','SHTFL'],
    '12':['Heat Index','K','HEATX'],
    '13':['Wind Chill Factor','K','WCF'],
    '14':['Minimum Dew Point Depression*','K','MINDPD'],
    '15':['Virtual Potential Temperature','K','VPTMP'],
    '16':['Snow Phase Change Heat Flux','W m-2','SNOHF'],
    '17':['Skin Temperature','K','SKINT'],
    '18':['Snow Temperature (top of snow)','K','SNOT'],
    '19':['Turbulent Transfer Coefficient for Heat','Numeric','TTCHT'],
    '20':['Turbulent Diffusion Coefficient for Heat','m2s-1','TDCHT'],
    '21':['Apparent Temperature **','K','APTMP'],
    '22':['Temperature Tendency due to Short-Wave Radiation','K s-1','TTSWR'],
    '23':['Temperature Tendency due to Long-Wave Radiation','K s-1','TTLWR'],
    '24':['Temperature Tendency due to Short-Wave Radiation,  Clear Sky','K s-1','TTSWRCS'],
    '25':['Temperature Tendency due to Long-Wave Radiation,  Clear Sky','K s-1','TTLWRCS'],
    '26':['Temperature Tendency due to parameterizations','K s-1','TTPARM'],
    '27':['Wet Bulb Temperature','K','WETBT'],
    '28':['Unbalanced Component of Temperature','K','UCTMP'],
    '29':['Temperature Advection','K s-1','TMPADV'],
    '30-191':['Reserved','unknown','unknown'],
    '192-254':['Reserved for Local Use','unknown','unknown'],
    '192':['Snow Phase Change Heat Flux','W m-2','SNOHF'],
    '193':['Temperature Tendency by All Radiation','K s-1','TTRAD'],
    '194':['Relative Error Variance','unknown','REV'],
    '195':['Large Scale Condensate Heating Rate','K s-1','LRGHR'],
    '196':['Deep Convective Heating Rate','K s-1','CNVHR'],
    '197':['Total Downward Heat Flux at Surface','W m-2','THFLX'],
    '198':['Temperature Tendency by All Physics','K s-1','TTDIA'],
    '199':['Temperature Tendency by Non-radiation Physics','K s-1','TTPHY'],
    '200':['Standard Dev. of IR Temp. over 1x1 deg. area','K','TSD1D'],
    '201':['Shallow Convective Heating Rate','K s-1','SHAHR'],
    '202':['Vertical Diffusion Heating rate','K s-1','VDFHR'],
    '203':['Potential Temperature at Top of Viscous Sublayer','K','THZ0'],
    '204':['Tropical Cyclone Heat Potential','Jm-2K','TCHP'],
    '205':['Effective Layer (EL) Temperature','C','ELMELT'],
    '206':['Wet Bulb Globe Temperature','K','WETGLBT'],
    '255':['Missing','unknown','unknown'],
    }
    table_4_2_0_1  = {
    '0':['Specific Humidity','kg kg-1','SPFH'],
    '1':['Relative Humidity','%','RH'],
    '2':['Humidity Mixing Ratio','kg kg-1','MIXR'],
    '3':['Precipitable Water','kg m-2','PWAT'],
    '4':['Vapour Pressure','Pa','VAPP'],
    '5':['Saturation Deficit','Pa','SATD'],
    '6':['Evaporation','kg m-2','EVP'],
    '7':['Precipitation Rate *','kg m-2 s-1','PRATE'],
    '8':['Total Precipitation ***','kg m-2','APCP'],
    '9':['Large-Scale Precipitation (non-convective) ***','kg m-2','NCPCP'],
    '10':['Convective Precipitation ***','kg m-2','ACPCP'],
    '11':['Snow Depth','m','SNOD'],
    '12':['Snowfall Rate Water Equivalent *','kg m-2 s-1','SRWEQ'],
    '13':['Water Equivalent of Accumulated Snow Depth ***','kg m-2','WEASD'],
    '14':['Convective Snow ***','kg m-2','SNOC'],
    '15':['Large-Scale Snow ***','kg m-2','SNOL'],
    '16':['Snow Melt','kg m-2','SNOM'],
    '17':['Snow Age','day','SNOAG'],
    '18':['Absolute Humidity','kg m-3','ABSH'],
    '19':['Precipitation Type','See Table 4.201','PTYPE'],
    '20':['Integrated Liquid Water','kg m-2','ILIQW'],
    '21':['Condensate','kg kg-1','TCOND'],
    '22':['Cloud Mixing Ratio','kg kg-1','CLMR'],
    '23':['Ice Water Mixing Ratio','kg kg-1','ICMR'],
    '24':['Rain Mixing Ratio','kg kg-1','RWMR'],
    '25':['Snow Mixing Ratio','kg kg-1','SNMR'],
    '26':['Horizontal Moisture Convergence','kg kg-1 s-1','MCONV'],
    '27':['Maximum Relative Humidity *','%','MAXRH'],
    '28':['Maximum Absolute Humidity *','kg m-3','MAXAH'],
    '29':['Total Snowfall ***','m','ASNOW'],
    '30':['Precipitable Water Category','See Table 4.202','PWCAT'],
    '31':['Hail','m','HAIL'],
    '32':['Graupel','kg kg-1','GRLE'],
    '33':['Categorical Rain','Code table 4.222','CRAIN'],
    '34':['Categorical Freezing Rain','Code table 4.222','CFRZR'],
    '35':['Categorical Ice Pellets','Code table 4.222','CICEP'],
    '36':['Categorical Snow','Code table 4.222','CSNOW'],
    '37':['Convective Precipitation Rate','kg m-2 s-1','CPRAT'],
    '38':['Horizontal Moisture Divergence','kg kg-1 s-1','MDIVER'],
    '39':['Percent frozen precipitation','%','CPOFP'],
    '40':['Potential Evaporation','kg m-2','PEVAP'],
    '41':['Potential Evaporation Rate','W m-2','PEVPR'],
    '42':['Snow Cover','%','SNOWC'],
    '43':['Rain Fraction of Total Cloud Water','Proportion','FRAIN'],
    '44':['Rime Factor','Numeric','RIME'],
    '45':['Total Column Integrated Rain','kg m-2','TCOLR'],
    '46':['Total Column Integrated Snow','kg m-2','TCOLS'],
    '47':['Large Scale Water Precipitation (Non-Convective) ***','kg m-2','LSWP'],
    '48':['Convective Water Precipitation ***','kg m-2','CWP'],
    '49':['Total Water Precipitation ***','kg m-2','TWATP'],
    '50':['Total Snow Precipitation ***','kg m-2','TSNOWP'],
    '51':['Total Column Water  (Vertically integrated total water (vapour+cloud water/ice)','kg m-2','TCWAT'],
    '52':['Total Precipitation Rate **','kg m-2 s-1','TPRATE'],
    '53':['Total Snowfall Rate Water Equivalent **','kg m-2 s-1','TSRWE'],
    '54':['Large Scale Precipitation Rate','kg m-2 s-1','LSPRATE'],
    '55':['Convective Snowfall Rate Water Equivalent','kg m-2 s-1','CSRWE'],
    '56':['Large Scale Snowfall Rate Water Equivalent','kg m-2 s-1','LSSRWE'],
    '57':['Total Snowfall Rate','m s-1','TSRATE'],
    '58':['Convective Snowfall Rate','m s-1','CSRATE'],
    '59':['Large Scale Snowfall Rate','m s-1','LSSRATE'],
    '60':['Snow Depth Water Equivalent','kg m-2','SDWE'],
    '61':['Snow Density','kg m-3','SDEN'],
    '62':['Snow Evaporation','kg m-2','SEVAP'],
    '63':['Reserved','unknown','unknown'],
    '64':['Total Column Integrated Water Vapour','kg m-2','TCIWV'],
    '65':['Rain Precipitation Rate','kg m-2 s-1','RPRATE'],
    '66':['Snow Precipitation Rate','kg m-2 s-1','SPRATE'],
    '67':['Freezing Rain Precipitation Rate','kg m-2 s-1','FPRATE'],
    '68':['Ice Pellets Precipitation Rate','kg m-2 s-1','IPRATE'],
    '69':['Total Column Integrate Cloud Water','kg m-2','TCOLW'],
    '70':['Total Column Integrate Cloud Ice','kg m-2','TCOLI'],
    '71':['Hail Mixing Ratio','kg kg-1','HAILMXR'],
    '72':['Total Column Integrate Hail','kg m-2','TCOLH'],
    '73':['Hail Prepitation Rate','kg m-2 s-1','HAILPR'],
    '74':['Total Column Integrate Graupel','kg m-2','TCOLG'],
    '75':['Graupel (Snow Pellets) Prepitation Rate','kg m-2 s-1','GPRATE'],
    '76':['Convective Rain Rate','kg m-2 s-1','CRRATE'],
    '77':['Large Scale Rain Rate','kg m-2 s-1','LSRRATE'],
    '78':['Total Column Integrate Water (All  components including precipitation)','kg m-2','TCOLWA'],
    '79':['Evaporation Rate','kg m-2 s-1','EVARATE'],
    '80':['Total Condensate','kg kg-1','TOTCON'],
    '81':['Total Column-Integrate Condensate','kg m-2','TCICON'],
    '82':['Cloud Ice Mixing Ratio','kg kg-1','CIMIXR'],
    '83':['Specific Cloud Liquid Water Content','kg kg-1','SCLLWC'],
    '84':['Specific Cloud Ice Water Content','kg kg-1','SCLIWC'],
    '85':['Specific Rain Water Content','kg kg-1','SRAINW'],
    '86':['Specific Snow Water Content','kg kg-1','SSNOWW'],
    '87':['Stratiform Precipitation Rate','kg m-2 s-1','STRPRATE'],
    '88':['Categorical Convective Precipitation','Code table 4.222','CATCP'],
    '89':['Reserved','unknown','unknown'],
    '90':['Total Kinematic Moisture Flux','kg kg-1 m s-1','TKMFLX'],
    '91':['U-component (zonal) Kinematic Moisture Flux','kg kg-1 m s-1','UKMFLX'],
    '92':['V-component (meridional) Kinematic Moisture Flux','kg kg-1 m s-1','VKMFLX'],
    '93':['Relative Humidity With Respect to Water','%','RHWATER'],
    '94':['Relative Humidity With Respect to Ice','%','RHICE'],
    '95':['Freezing or Frozen Precipitation Rate','kg m-2 s-1','FZPRATE'],
    '96':['Mass Density of Rain','kg m-3','MASSDR'],
    '97':['Mass Density of Snow','kg m-3','MASSDS'],
    '98':['Mass Density of Graupel','kg m-3','MASSDG'],
    '99':['Mass Density of Hail','kg m-3','MASSDH'],
    '100':['Specific Number Concentration of Rain','kg-1','SPNCR'],
    '101':['Specific Number Concentration of Snow','kg-1','SPNCS'],
    '102':['Specific Number Concentration of Graupel','kg-1','SPNCG'],
    '103':['Specific Number Concentration of Hail','kg-1','SPNCH'],
    '104':['Number Density of Rain','m-3','NUMDR'],
    '105':['Number Density of Snow','m-3','NUMDS'],
    '106':['Number Density of Graupel','m-3','NUMDG'],
    '107':['Number Density of Hail','m-3','NUMDH'],
    '108':['Specific Humidity Tendency due to Parameterizations','kg kg-1 s-1','SHTPRM'],
    '109':['Mass Density of Liquid Water Coating on Hail  Expressed as Mass of Liquid Water per Unit Volume of Air','kg m-3','MDLWHVA'],
    '110':['Specific Mass of Liquid Water Coating on Hail Expressed as Mass of Liquid Water per Unit Mass of Moist Air','kg kg-1','SMLWHMA'],
    '111':['Mass Mixing Ratio of Liquid Water Coating on Hail Expressed as Mass of Liquid Water per Unit Mass of Dry Air','kg kg-1','MMLWHDA'],
    '112':['Mass Density of Liquid Water Coating on Graupel Expressed as Mass of Liquid Water per Unit Volume of Air','kg m-3','MDLWGVA'],
    '113':['Specific Mass of Liquid Water Coating on Graupel  Expressed as Mass of Liquid Water per Unit Mass of Moist Air','kg kg-1','SMLWGMA'],
    '114':['Mass Mixing Ratio of Liquid Water Coating on Graupel  Expressed as Mass of Liquid Water per Unit Mass of Dry Air','kg kg-1','MMLWGDA'],
    '115':['Mass Density of Liquid Water Coating on Snow  Expressed as Mass of Liquid Water per Unit Volume of Air','kg m-3','MDLWSVA'],
    '116':['Specific Mass of Liquid Water Coating on Snow  Expressed as Mass of Liquid Water per Unit Mass of Moist Air','kg kg-1','SMLWSMA'],
    '117':['Mass Mixing Ratio of Liquid Water Coating on Snow  Expressed as Mass of Liquid Water per Unit Mass of Dry Air','kg kg-1','MMLWSDA'],
    '118':['Unbalanced Component of Specific Humidity','kg kg-1','UNCSH'],
    '119':['Unbalanced Component of Specific Cloud Liquid Water content','kg kg-1','UCSCLW'],
    '120':['Unbalanced Component of Specific Cloud Ice Water content','kg kg-1','UCSCIW'],
    '121':['Fraction of Snow Cover','Proportion','FSNOWC'],
    '122-128':['Reserved','unknown','unknown'],
    '129':['Effective Radius of Cloud Water','m','EFRCWAT'],
    '130':['Effective Radius of Rain','m','EFRRAIN'],
    '131':['Effective Radius of Cloud Ice','m','EFRCICE'],
    '132':['Effective Radius of Snow','m','EFRSNOW'],
    '133':['Effective Radius of Graupel','m','EFRGRL'],
    '134':['Effective Radius of Hail','m','EFRHAIL'],
    '135':['Effective Radius of Subgrid Liquid Clouds','m','EFRSLC'],
    '136':['Effective Radius of Subgrid Ice Clouds','m','EFRSICEC'],
    '137':['Effective Aspect Ratio of Rain','unknown','EFARRAIN'],
    '138':['Effective Aspect Ratio of Cloud Ice','unknown','EFARCICE'],
    '139':['Effective Aspect Ratio of Snow','unknown','EFARSNOW'],
    '140':['Effective Aspect Ratio of Graupel','unknown','EFARGRL'],
    '141':['Effective Aspect Ratio of Hail','unknown','EFARHAIL'],
    '142':['Effective Aspect Ratio of Subgrid Ice Clouds','unknown','EFARSIC'],
    '143-191':['Reserved','unknown','unknown'],
    '192-254':['Reserved for Local Use','unknown','unknown'],
    '192':['Categorical Rain','Code table 4.222','CRAIN'],
    '193':['Categorical Freezing Rain','Code table 4.222','CFRZR'],
    '194':['Categorical Ice Pellets','Code table 4.222','CICEP'],
    '195':['Categorical Snow','Code table 4.222','CSNOW'],
    '196':['Convective Precipitation Rate','kg m-2 s-1','CPRAT'],
    '197':['Horizontal Moisture Divergence','kg kg-1 s-1','MDIV'],
    '198':['Minimum Relative Humidity','%','MINRH'],
    '199':['Potential Evaporation','kg m-2','PEVAP'],
    '200':['Potential Evaporation Rate','W m-2','PEVPR'],
    '201':['Snow Cover','%','SNOWC'],
    '202':['Rain Fraction of Total Liquid Water','non-dim','FRAIN'],
    '203':['Rime Factor','non-dim','RIME'],
    '204':['Total Column Integrated Rain','kg m-2','TCOLR'],
    '205':['Total Column Integrated Snow','kg m-2','TCOLS'],
    '206':['Total Icing Potential Diagnostic','non-dim','TIPD'],
    '207':['Number concentration for ice particles','non-dim','NCIP'],
    '208':['Snow temperature','K','SNOT'],
    '209':['Total column-integrated supercooled liquid water','kg m-2','TCLSW'],
    '210':['Total column-integrated melting ice','kg m-2','TCOLM'],
    '211':['Evaporation - Precipitation','cm/day','EMNP'],
    '212':['Sublimation (evaporation from snow)','W m-2','SBSNO'],
    '213':['Deep Convective Moistening Rate','kg kg-1 s-1','CNVMR'],
    '214':['Shallow Convective Moistening Rate','kg kg-1 s-1','SHAMR'],
    '215':['Vertical Diffusion Moistening Rate','kg kg-1 s-1','VDFMR'],
    '216':['Condensation Pressure of Parcali  Lifted From Indicate Surface','Pa','CONDP'],
    '217':['Large scale moistening rate','kg kg-1 s-1','LRGMR'],
    '218':['Specific humidity at top of viscous sublayer','kg kg-1','QZ0'],
    '219':['Maximum specific humidity at 2m','kg kg-1','QMAX'],
    '220':['Minimum specific humidity at 2m','kg kg-1','QMIN'],
    '221':['Liquid precipitation (Rainfall)','kg m-2','ARAIN'],
    '222':['Snow temperature, depth-avg','K','SNOWT'],
    '223':['Total precipitation (nearest grid point)','kg m-2','APCPN'],
    '224':['Convective precipitation (nearest grid point)','kg m-2','ACPCPN'],
    '225':['Freezing Rain','kg m-2','FRZR'],
    '226':['Predominant Weather','Numeric','PWTHER'],
    '227':['Frozen Rain','kg m-2','FROZR'],
    '228':['Flat Ice Accumulation (FRAM)','kg m-2','FICEAC'],
    '229':['Line Ice Accumulation (FRAM)','kg m-2','LICEAC'],
    '230':['Sleet Accumulation','kg m-2','SLACC'],
    '231':['Precipitation Potential Index','%','PPINDX'],
    '232':['Probability Cloud Ice Present','%','PROBCIP'],
    '233':['Snow Liquid ratio','kg kg-1','SNOWLR'],
    '234':['Precipitation Duration','hour','PCPDUR'],
    '235':['Cloud Liquid Mixing Ratio','kg kg-1','CLLMR'],
    '236-240':['Reserved','unknown','unknown'],
    '241':['Total Snow','kg m-2','TSNOW'],
    '242':['Relative Humidity with Respect to Precipitable Water','%','RHPW'],
    '245':['Hourly Maximum of Column Vertical Integrated Graupel on Entire Atmosphere','kg m-2','MAXVIG'],
    '255':['Missing','unknown','unknown'],
    }
    table_4_2_0_2  = {
    '0':['Wind Direction (from which blowing)','°','WDIR'],
    '1':['Wind Speed','m s-1','WIND'],
    '2':['U-Component of Wind','m s-1','UGRD'],
    '3':['V-Component of Wind','m s-1','VGRD'],
    '4':['Stream Function','m2 s-1','STRM'],
    '5':['Velocity Potential','m2 s-1','VPOT'],
    '6':['Montgomery Stream Function','m2 s-2','MNTSF'],
    '7':['Sigma Coordinate Vertical Velocity','s-1','SGCVV'],
    '8':['Vertical Velocity (Pressure)','Pa s-1','VVEL'],
    '9':['Vertical Velocity (Geometric)','m s-1','DZDT'],
    '10':['Absolute Vorticity','s-1','ABSV'],
    '11':['Absolute Divergence','s-1','ABSD'],
    '12':['Relative Vorticity','s-1','RELV'],
    '13':['Relative Divergence','s-1','RELD'],
    '14':['Potential Vorticity','K m2 kg-1 s-1','PVORT'],
    '15':['Vertical U-Component Shear','s-1','VUCSH'],
    '16':['Vertical V-Component Shear','s-1','VVCSH'],
    '17':['Momentum Flux, U-Component','N m-2','UFLX'],
    '18':['Momentum Flux, V-Component','N m-2','VFLX'],
    '19':['Wind Mixing Energy','J','WMIXE'],
    '20':['Boundary Layer Dissipation','W m-2','BLYDP'],
    '21':['Maximum Wind Speed *','m s-1','MAXGUST'],
    '22':['Wind Speed (Gust)','m s-1','GUST'],
    '23':['U-Component of Wind (Gust)','m s-1','UGUST'],
    '24':['V-Component of Wind (Gust)','m s-1','VGUST'],
    '25':['Vertical Speed Shear','s-1','VWSH'],
    '26':['Horizontal Momentum Flux','N m-2','MFLX'],
    '27':['U-Component Storm Motion','m s-1','USTM'],
    '28':['V-Component Storm Motion','m s-1','VSTM'],
    '29':['Drag Coefficient','Numeric','CD'],
    '30':['Frictional Velocity','m s-1','FRICV'],
    '31':['Turbulent Diffusion Coefficient for Momentum','m2 s-1','TDCMOM'],
    '32':['Eta Coordinate Vertical Velocity','s-1','ETACVV'],
    '33':['Wind Fetch','m','WINDF'],
    '34':['Normal Wind Component **','m s-1','NWIND'],
    '35':['Tangential Wind Component **','m s-1','TWIND'],
    '36':['Amplitude Function for Rossby Wave Envelope for Meridional Wind ***','m s-1','AFRWE'],
    '37':['Northward Turbulent Surface Stress ****','N m-2 s','NTSS'],
    '38':['Eastward Turbulent Surface Stress ****','N m-2 s','ETSS'],
    '39':['Eastward Wind Tendency Due to Parameterizations','m s-2','EWTPARM'],
    '40':['Northward Wind Tendency Due to Parameterizations','m s-2','NWTPARM'],
    '41':['U-Component of Geostrophic Wind','m s-1','UGWIND'],
    '42':['V-Component of Geostrophic Wind','m s-1','VGWIND'],
    '43':['Geostrophic Wind Direction','°','GEOWD'],
    '44':['Geostrophic Wind Speed','m s-1','GEOWS'],
    '45':['Unbalanced Component of Divergence','s-1','UNDIV'],
    '46':['Vorticity Advection','s-2','VORTADV'],
    '47-191':['Reserved','unknown','unknown'],
    '192-254':['Reserved for Local Use','unknown','unknown'],
    '192':['Vertical Speed Shear','s-1','VWSH'],
    '193':['Horizontal Momentum Flux','N m-2','MFLX'],
    '194':['U-Component Storm Motion','m s-1','USTM'],
    '195':['V-Component Storm Motion','m s-1','VSTM'],
    '196':['Drag Coefficient','non-dim','CD'],
    '197':['Frictional Velocity','m s-1','FRICV'],
    '198':['Latitude of U Wind Component of  Velocity','deg','LAUV'],
    '199':['Longitude of U Wind Component of Velocity','deg','LOUV'],
    '200':['Latitude of V Wind Component of Velocity','deg','LAVV'],
    '201':['Longitude of V Wind Component of Velocity','deg','LOVV'],
    '202':['Latitude of Presure Point','deg','LAPP'],
    '203':['Longitude of Presure Point','deg','LOPP'],
    '204':['Vertical Eddy Diffusivity Heat exchange','m2 s-1','VEDH'],
    '205':['Covariance between Meridional and Zonal  Components of the wind.','m2 s-2','COVMZ'],
    '206':['Covariance between Temperature and Zonal  Components of the wind.','K*m s-1','COVTZ'],
    '207':['Covariance between Temperature and Meridional  Components of the wind.','K*m s-1','COVTM'],
    '208':['Vertical Diffusion Zonal Acceleration','m s-2','VDFUA'],
    '209':['Vertical Diffusion Meridional Acceleration','m s-2','VDFVA'],
    '210':['Gravity wave drag zonal acceleration','m s-2','GWDU'],
    '211':['Gravity wave drag meridional acceleration','m s-2','GWDV'],
    '212':['Convective zonal momentum mixing acceleration','m s-2','CNVU'],
    '213':['Convective meridional momentum mixing acceleration','m s-2','CNVV'],
    '214':['Tendency of vertical velocity','m s-2','WTEND'],
    '215':['Omega (Dp/Dt) divide by density','K','OMGALF'],
    '216':['Convective Gravity wave drag zonal acceleration','m s-2','CNGWDU'],
    '217':['Convective Gravity wave drag meridional acceleration','m s-2','CNGWDV'],
    '218':['Velocity Point Model Surface','unknown','LMV'],
    '219':['Potential Vorticity (Mass-Weighted)','1/s/m','PVMWW'],
    '220':['Hourly Maximum of Upward Vertical Velocity','m s-1','MAXUVV'],
    '221':['Hourly Maximum of Downward Vertical Velocity','m s-1','MAXDVV'],
    '222':['U Component of Hourly Maximum 10m Wind Speed','m s-1','MAXUW'],
    '223':['V Component of Hourly Maximum 10m Wind Speed','m s-1','MAXVW'],
    '224':['Ventilation Rate','m2 s-1','VRATE'],
    '225':['Transport Wind Speed','m s-1','TRWSPD'],
    '226':['Transport Wind Direction','Deg','TRWDIR'],
    '227':['Earliest Reasonable Arrival Time (10% exceedance)','s','TOA10'],
    '228':['Most Likely Arrival Time (50% exceedance)','s','TOA50'],
    '229':['Most Likely Departure Time (50% exceedance)','s','TOD50'],
    '230':['Latest Reasonable Departure Time (90% exceedance)','s','TOD90'],
    '231':['Tropical Wind Direction','°','TPWDIR'],
    '232':['Tropical Wind Speed','m s-1','TPWSPD'],
    '233':['Inflow Based (ESFC) to 50% EL Shear Magnitude','kt','ESHR'],
    '234':['U Component Inflow Based to 50% EL Shear Vector','kt','UESH'],
    '235':['V Component Inflow Based to 50% EL Shear Vector','kt','VESH'],
    '236':['U Component Bunkers Effective Right Motion','kt','UEID'],
    '237':['V Component Bunkers Effective Right Motion','kt','VEID'],
    '255':['Missing','unknown','unknown'],
    }
    table_4_2_0_3  = {
    '0':['Pressure','Pa','PRES'],
    '1':['Pressure Reduced to MSL','Pa','PRMSL'],
    '2':['Pressure Tendency','Pa s-1','PTEND'],
    '3':['ICAO Standard Atmosphere Reference Height','m','ICAHT'],
    '4':['Geopotential','m2 s-2','GP'],
    '5':['Geopotential Height','gpm','HGT'],
    '6':['Geometric Height','m','DIST'],
    '7':['Standard Deviation of Height','m','HSTDV'],
    '8':['Pressure Anomaly','Pa','PRESA'],
    '9':['Geopotential Height Anomaly','gpm','GPA'],
    '10':['Density','kg m-3','DEN'],
    '11':['Altimeter Setting','Pa','ALTS'],
    '12':['Thickness','m','THICK'],
    '13':['Pressure Altitude','m','PRESALT'],
    '14':['Density Altitude','m','DENALT'],
    '15':['5-Wave Geopotential Height','gpm','5WAVH'],
    '16':['Zonal Flux of Gravity Wave Stress','N m-2','U-GWD'],
    '17':['Meridional Flux of Gravity Wave Stress','N m-2','V-GWD'],
    '18':['Planetary Boundary Layer Height','m','HPBL'],
    '19':['5-Wave Geopotential Height Anomaly','gpm','5WAVA'],
    '20':['Standard Deviation of Sub-Grid Scale Orography','m','SDSGSO'],
    '21':['Angle of Sub-Grid Scale Orography','rad','AOSGSO'],
    '22':['Slope of Sub-Grid Scale Orography','Numeric','SSGSO'],
    '23':['Gravity Wave Dissipation','W m-2','GWD'],
    '24':['Anisotropy of Sub-Grid Scale Orography','Numeric','ASGSO'],
    '25':['Natural Logarithm of Pressure in Pa','Numeric','NLPRES'],
    '26':['Exner Pressure','Numeric','EXPRES'],
    '27':['Updraught Mass Flux','kg m-2 s-1','UMFLX'],
    '28':['Downdraught Mass Flux','kg m-2 s-1','DMFLX'],
    '29':['Updraught Detrainment Rate','kg m-3 s-1','UDRATE'],
    '30':['Downdraught Detrainment Rate','kg m-3 s-1','DDRATE'],
    '31':['Unbalanced Component of Logarithm of Surface Pressure','unknown','UCLSPRS'],
    '32-191':['Reserved','unknown','unknown'],
    '192-254':['Reserved for Local Use','unknown','unknown'],
    '192':['MSLP (Eta model reduction)','Pa','MSLET'],
    '193':['5-Wave Geopotential Height','gpm','5WAVH'],
    '194':['Zonal Flux of Gravity Wave Stress','N m-2','U-GWD'],
    '195':['Meridional Flux of Gravity Wave Stress','N m-2','V-GWD'],
    '196':['Planetary Boundary Layer Height','m','HPBL'],
    '197':['5-Wave Geopotential Height Anomaly','gpm','5WAVA'],
    '198':['MSLP (MAPS System Reduction)','Pa','MSLMA'],
    '199':['3-hr pressure tendency (Std. Atmos. Reduction)','Pa s-1','TSLSA'],
    '200':['Pressure of level from which parcel was lifted','Pa','PLPL'],
    '201':['X-gradient of Log Pressure','m-1','LPSX'],
    '202':['Y-gradient of Log  Pressure','m-1','LPSY'],
    '203':['X-gradient of Height','m-1','HGTX'],
    '204':['Y-gradient of Height','m-1','HGTY'],
    '205':['Layer Thickness','m','LAYTH'],
    '206':['Natural Log of Surface Pressure','ln (kPa)','NLGSP'],
    '207':['Convective updraft mass flux','kg m-2 s-1','CNVUMF'],
    '208':['Convective downdraft mass flux','kg m-2 s-1','CNVDMF'],
    '209':['Convective detrainment mass flux','kg m-2 s-1','CNVDEMF'],
    '210':['Mass Point Model Surface','unknown','LMH'],
    '211':['Geopotential Height (nearest grid point)','gpm','HGTN'],
    '212':['Pressure (nearest grid point)','Pa','PRESN'],
    '213':['Orographic Convexity','unknown','ORCONV'],
    '214':['Orographic Asymmetry, W Component','unknown','ORASW'],
    '215':['Orographic Asymmetry, S Component','unknown','ORASS'],
    '216':['Orographic Asymmetry, SW Component','unknown','ORASSW'],
    '217':['Orographic Asymmetry, NW Component','unknown','ORASNW'],
    '218':['Orographic Length Scale, W Component','unknown','ORLSW'],
    '219':['Orographic Length Scale, S Component','unknown','ORLSS'],
    '220':['Orographic Length Scale, SW Component','unknown','ORLSSW'],
    '221':['Orographic Length Scale, NW Component','unknown','ORLSNW'],
    '222':['Effective Surface Height','m','EFSH'],
    '255':['Missing','unknown','unknown'],
    }
    table_4_2_0_4  = {
    '0':['Net Short-Wave Radiation Flux (Surface)*','W m-2','NSWRS'],
    '1':['Net Short-Wave Radiation Flux (Top of Atmosphere)*','W m-2','NSWRT'],
    '2':['Short-Wave Radiation Flux*','W m-2','SWAVR'],
    '3':['Global Radiation Flux','W m-2','GRAD'],
    '4':['Brightness Temperature','K','BRTMP'],
    '5':['Radiance (with respect to wave number)','W m-1 sr-1','LWRAD'],
    '6':['Radiance (with respect to wavelength)','W m-3 sr-1','SWRAD'],
    '7':['Downward Short-Wave Radiation Flux','W m-2','DSWRF'],
    '8':['Upward Short-Wave Radiation Flux','W m-2','USWRF'],
    '9':['Net Short Wave Radiation Flux','W m-2','NSWRF'],
    '10':['Photosynthetically Active Radiation','W m-2','PHOTAR'],
    '11':['Net Short-Wave Radiation Flux, Clear Sky','W m-2','NSWRFCS'],
    '12':['Downward UV Radiation','W m-2','DWUVR'],
    '13':['Direct Short Wave Radiation Flux','W m-2','DSWRFLX'],
    '14':['Diffuse Short Wave Radiation Flux','W m-2','DIFSWRF'],
    '15-49':['Reserved','unknown','unknown'],
    '50':['UV Index (Under Clear Sky)**','Numeric','UVIUCS'],
    '51':['UV Index**','W m-2','UVI'],
    '52':['Downward Short-Wave Radiation Flux, Clear Sky','W m-2','DSWRFCS'],
    '53':['Upward Short-Wave Radiation Flux, Clear Sky','W m-2','USWRFCS'],
    '54-191':['Reserved','unknown','unknown'],
    '192-254':['Reserved for Local Use','unknown','unknown'],
    '192':['Downward Short-Wave Radiation Flux','W m-2','DSWRF'],
    '193':['Upward Short-Wave Radiation Flux','W m-2','USWRF'],
    '194':['UV-B Downward Solar Flux','W m-2','DUVB'],
    '195':['Clear sky UV-B Downward Solar Flux','W m-2','CDUVB'],
    '196':['Clear Sky Downward Solar Flux','W m-2','CSDSF'],
    '197':['Solar Radiative Heating Rate','K s-1','SWHR'],
    '198':['Clear Sky Upward Solar Flux','W m-2','CSUSF'],
    '199':['Cloud Forcing Net Solar Flux','W m-2','CFNSF'],
    '200':['Visible Beam Downward Solar Flux','W m-2','VBDSF'],
    '201':['Visible Diffuse Downward Solar Flux','W m-2','VDDSF'],
    '202':['Near IR Beam Downward Solar Flux','W m-2','NBDSF'],
    '203':['Near IR Diffuse Downward Solar Flux','W m-2','NDDSF'],
    '204':['Downward Total Radiation Flux','W m-2','DTRF'],
    '205':['Upward Total Radiation Flux','W m-2','UTRF'],
    '255':['Missing','unknown','unknown'],
    }
    table_4_2_0_5  = {
    '0':['Net Long-Wave Radiation Flux (Surface)*','W m-2','NLWRS'],
    '1':['Net Long-Wave Radiation Flux (Top of Atmosphere)*','W m-2','NLWRT'],
    '2':['Long-Wave Radiation Flux*','W m-2','LWAVR'],
    '3':['Downward Long-Wave Rad. Flux','W m-2','DLWRF'],
    '4':['Upward Long-Wave Rad. Flux','W m-2','ULWRF'],
    '5':['Net Long-Wave Radiation Flux','W m-2','NLWRF'],
    '6':['Net Long-Wave Radiation Flux, Clear Sky','W m-2','NLWRCS'],
    '7':['Brightness Temperature','K','BRTEMP'],
    '8':['Downward Long-Wave Radiation Flux, Clear Sky','W m-2','DLWRFCS'],
    '9-191':['Reserved','unknown','unknown'],
    '192-254':['Reserved for Local Use','unknown','unknown'],
    '192':['Downward Long-Wave Rad. Flux','W m-2','DLWRF'],
    '193':['Upward Long-Wave Rad. Flux','W m-2','ULWRF'],
    '194':['Long-Wave Radiative Heating Rate','K s-1','LWHR'],
    '195':['Clear Sky Upward Long Wave Flux','W m-2','CSULF'],
    '196':['Clear Sky Downward Long Wave Flux','W m-2','CSDLF'],
    '197':['Cloud Forcing Net Long Wave Flux','W m-2','CFNLF'],
    '255':['Missing','unknown','unknown'],
    }
    table_4_2_0_6  = {
    '0':['Cloud Ice','kg m-2','CICE'],
    '1':['Total Cloud Cover','%','TCDC'],
    '2':['Convective Cloud Cover','%','CDCON'],
    '3':['Low Cloud Cover','%','LCDC'],
    '4':['Medium Cloud Cover','%','MCDC'],
    '5':['High Cloud Cover','%','HCDC'],
    '6':['Cloud Water','kg m-2','CWAT'],
    '7':['Cloud Amount','%','CDCA'],
    '8':['Cloud Type','See Table 4.203','CDCT'],
    '9':['Thunderstorm Maximum Tops','m','TMAXT'],
    '10':['Thunderstorm Coverage','See Table 4.204','THUNC'],
    '11':['Cloud Base','m','CDCB'],
    '12':['Cloud Top','m','CDCTOP'],
    '13':['Ceiling','m','CEIL'],
    '14':['Non-Convective Cloud Cover','%','CDLYR'],
    '15':['Cloud Work Function','J kg-1','CWORK'],
    '16':['Convective Cloud Efficiency','Proportion','CUEFI'],
    '17':['Total Condensate * - Parameter deprecated','kg kg-1','TCONDO'],
    '18':['Total Column-Integrated Cloud Water * - Parameter deprecated','kg m-2','TCOLWO'],
    '19':['Total Column-Integrated Cloud Ice * - Parameter deprecated','kg m-2','TCOLIO'],
    '20':['Total Column-Integrated Condensate * - Parameter deprecated','kg m-2','TCOLC'],
    '21':['Ice fraction of total condensate','Proportion','FICE'],
    '22':['Cloud Cover','%','CDCC'],
    '23':['Cloud Ice Mixing Ratio * - Parameter deprecated','kg kg-1','CDCIMR'],
    '24':['Sunshine','Numeric','SUNS'],
    '25':['Horizontal Extent of Cumulonimbus (CB)','%','CBHE'],
    '26':['Height of Convective Cloud Base','m','HCONCB'],
    '27':['Height of Convective Cloud Top','m','HCONCT'],
    '28':['Number Concentration of Cloud Droplets','kg-1','NCONCD'],
    '29':['Number Concentration of Cloud Ice','kg-1','NCCICE'],
    '30':['Number Density of Cloud Droplets','m-3','NDENCD'],
    '31':['Number Density of Cloud Ice','m-3','NDCICE'],
    '32':['Fraction of Cloud Cover','Numeric','FRACCC'],
    '33':['Sunshine Duration','s','SUNSD'],
    '34':['Surface Long Wave Effective Total Cloudiness','Numeric','SLWTC'],
    '35':['Surface Short Wave Effective Total Cloudiness','Numeric','SSWTC'],
    '36':['Fraction of Stratiform Precipitation Cover','Proportion','FSTRPC'],
    '37':['Fraction of Convective Precipitation Cover','Proportion','FCONPC'],
    '38':['Mass Density of Cloud Droplets','kg m-3','MASSDCD'],
    '39':['Mass Density of Cloud Ice','kg m-3','MASSDCI'],
    '40':['Mass Density of Convective Cloud Water Droplets','kg m-3','MDCCWD'],
    '41-46':['Reserved','unknown','unknown'],
    '47':['Volume Fraction of Cloud Water Droplets **','Numeric','VFRCWD'],
    '48':['Volume Fraction of Cloud Ice Particles **','Numeric','VFRCICE'],
    '49':['Volume Fraction of Cloud (Ice and/or Water) **','Numeric','VFRCIW'],
    '50-191':['Reserved','unknown','unknown'],
    '192-254':['Reserved for Local Use','unknown','unknown'],
    '192':['Non-Convective Cloud Cover','%','CDLYR'],
    '193':['Cloud Work Function','J kg-1','CWORK'],
    '194':['Convective Cloud Efficiency','non-dim','CUEFI'],
    '195':['Total Condensate','kg kg-1','TCOND'],
    '196':['Total Column-Integrated Cloud Water','kg m-2','TCOLW'],
    '197':['Total Column-Integrated Cloud Ice','kg m-2','TCOLI'],
    '198':['Total Column-Integrated Condensate','kg m-2','TCOLC'],
    '199':['Ice fraction of total condensate','non-dim','FICE'],
    '200':['Convective Cloud Mass Flux','Pa s-1','MFLUX'],
    '201':['Sunshine Duration','s','SUNSD'],
    '255':['Missing','unknown','unknown'],
    }
    table_4_2_0_7  = {
    '0':['Parcel Lifted Index (to 500 hPa)','K','PLI'],
    '1':['Best Lifted Index (to 500 hPa)','K','BLI'],
    '2':['K Index','K','KX'],
    '3':['KO Index','K','KOX'],
    '4':['Total Totals Index','K','TOTALX'],
    '5':['Sweat Index','Numeric','SX'],
    '6':['Convective Available Potential Energy','J kg-1','CAPE'],
    '7':['Convective Inhibition','J kg-1','CIN'],
    '8':['Storm Relative Helicity','m2 s-2','HLCY'],
    '9':['Energy Helicity Index','Numeric','EHLX'],
    '10':['Surface Lifted Index','K','LFT X'],
    '11':['Best (4 layer) Lifted Index','K','4LFTX'],
    '12':['Richardson Number','Numeric','RI'],
    '13':['Showalter Index','K','SHWINX'],
    '14':['Reserved','unknown','unknown'],
    '15':['Updraft Helicity','m2 s-2','UPHL'],
    '16':['Bulk Richardson Number','Numeric','BLKRN'],
    '17':['Gradient Richardson Number','Numeric','GRDRN'],
    '18':['Flux Richardson Number','Numeric','FLXRN'],
    '19':['Convective Available Potential Energy Shear','m2 s-2','CONAPES'],
    '20-191':['Reserved','unknown','unknown'],
    '192-254':['Reserved for Local Use','unknown','unknown'],
    '192':['Surface Lifted Index','K','LFT X'],
    '193':['Best (4 layer) Lifted Index','K','4LFTX'],
    '194':['Richardson Number','Numeric','RI'],
    '195':['Convective Weather Detection Index','unknown','CWDI'],
    '196':['Ultra Violet Index','W m-2','UVI'],
    '197':['Updraft Helicity','m2 s-2','UPHL'],
    '198':['Leaf Area Index','Numeric','LAI'],
    '199':['Hourly Maximum of Updraft Helicity','m2 s-2','MXUPHL'],
    '200':['Hourly Minimum of Updraft Helicity','m2 s-2','MNUPHL'],
    '201':['Bourgoiun Negative Energy Layer (surface to freezing level)','J kg-1','BNEGELAY'],
    '202':['Bourgoiun Positive Energy Layer (2k ft AGL to 400 hPa)','J kg-1','BPOSELAY'],
    '203':['Downdraft CAPE','J kg-1','DCAPE'],
    '204':['Effective Storm Relative Helicity','m2 s-2','EFHL'],
    '205':['Enhanced Stretching Potential','Numeric','ESP'],
    '206':['Critical Angle','Degree','CANGLE'],
    '207':['Effective Surface Helicity','m2 s-2','E3KH'],
    '208':['Significant Tornado Parameter with CIN-Effective Layer','numeric','STPC'],
    '209':['Significant Hail Parameter','numeric','SIGH'],
    '210':['Supercell Composite Parameter-Effective Layer','numeric','SCCP'],
    '211':['Significant Tornado parameter-Fixed Layer','numeric','SIGT'],
    '212':['Mixed Layer (100 mb) Virtual LFC','numeric','MLFC'],
    '255':['Missing','unknown','unknown'],
    }
    table_4_2_0_13  = {
    '0':['Aerosol Type','See Table 4.205','AEROT'],
    '1-191':['Reserved','unknown','unknown'],
    '192-254':['Reserved for Local Use','unknown','unknown'],
    '192':['Particulate matter (coarse)','µg m-3','PMTC'],
    '193':['Particulate matter (fine)','µg m-3','PMTF'],
    '194':['Particulate matter (fine)','log10 (µg m-3)','LPMTF'],
    '195':['Integrated column particulate matter (fine)','log10 (µg m-3)','LIPMF'],
    '255':['Missing','unknown','unknown'],
    }
    table_4_2_0_14  = {
    '0':['Total Ozone','DU','TOZNE'],
    '1':['Ozone Mixing Ratio','kg kg-1','O3MR'],
    '2':['Total Column Integrated Ozone','DU','TCIOZ'],
    '3-191':['Reserved','unknown','unknown'],
    '192-254':['Reserved for Local Use','unknown','unknown'],
    '192':['Ozone Mixing Ratio','kg kg-1','O3MR'],
    '193':['Ozone Concentration','ppb','OZCON'],
    '194':['Categorical Ozone Concentration','Non-Dim','OZCAT'],
    '195':['Ozone Vertical Diffusion','kg kg-1 s-1','VDFOZ'],
    '196':['Ozone Production','kg kg-1 s-1','POZ'],
    '197':['Ozone Tendency','kg kg-1 s-1','TOZ'],
    '198':['Ozone Production from Temperature Term','kg kg-1 s-1','POZT'],
    '199':['Ozone Production from Column Ozone Term','kg kg-1 s-1','POZO'],
    '200':['Ozone Daily Max from 1-hour Average','ppbV','OZMAX1'],
    '201':['Ozone Daily Max from 8-hour Average','ppbV','OZMAX8'],
    '202':['PM 2.5 Daily Max from 1-hour Average','μg m-3','PDMAX1'],
    '203':['PM 2.5 Daily Max from 24-hour Average','μg m-3','PDMAX24'],
    '204':['Acetaldehyde & Higher Aldehydes','ppbV','ALD2'],
    '255':['Missing','unknown','unknown'],
    }
    table_4_2_0_15  = {
    '0':['Base Spectrum Width','m s-1','BSWID'],
    '1':['Base Reflectivity','dB','BREF'],
    '2':['Base Radial Velocity','m s-1','BRVEL'],
    '3':['Vertically-Integrated Liquid Water','kg m-2','VIL'],
    '4':['Layer Maximum Base Reflectivity','dB','LMAXBR'],
    '5':['Precipitation','kg m-2','PREC'],
    '6':['Radar Spectra (1)','unknown','RDSP1'],
    '7':['Radar Spectra (2)','unknown','RDSP2'],
    '8':['Radar Spectra (3)','unknown','RDSP3'],
    '9':['Reflectivity of Cloud Droplets','dB','RFCD'],
    '10':['Reflectivity of Cloud Ice','dB','RFCI'],
    '11':['Reflectivity of Snow','dB','RFSNOW'],
    '12':['Reflectivity of Rain','dB','RFRAIN'],
    '13':['Reflectivity of Graupel','dB','RFGRPL'],
    '14':['Reflectivity of Hail','dB','RFHAIL'],
    '15':['Hybrid Scan Reflectivity','dB','HSR'],
    '16':['Hybrid Scan Reflectivity Height','m','HSRHT'],
    '17-191':['Reserved','unknown','unknown'],
    '192-254':['Reserved for Local Use','unknown','unknown'],
    '255':['Missing','unknown','unknown'],
    }
    table_4_2_0_16  = {
    '0':['Equivalent radar reflectivity factor for rain','m m6 m-3','REFZR'],
    '1':['Equivalent radar reflectivity factor for snow','m m6 m-3','REFZI'],
    '2':['Equivalent radar reflectivity factor for parameterized convection','m m6 m-3','REFZC'],
    '3':['Echo Top','m','RETOP'],
    '4':['Reflectivity','dB','REFD'],
    '5':['Composite reflectivity','dB','REFC'],
    '6-191':['Reserved','unknown','unknown'],
    '192-254':['Reserved for Local Use','unknown','unknown'],
    '192':['Equivalent radar reflectivity factor for rain','m m6 m-3','REFZR'],
    '193':['Equivalent radar reflectivity factor for snow','m m6 m-3','REFZI'],
    '194':['Equivalent radar reflectivity factor for parameterized convection','m m6 m-3','REFZC'],
    '195':['Reflectivity','dB','REFD'],
    '196':['Composite reflectivity','dB','REFC'],
    '197':['Echo Top','m','RETOP'],
    '198':['Hourly Maximum of Simulated Reflectivity','dB','MAXREF'],
    '255':['Missing','unknown','unknown'],
    }
    table_4_2_0_17  = {
    '0':['Lightning Strike Density','m-2 s-1','LTNGSD'],
    '1':['Lightning Potential Index (LPI)','J kg-1','LTPINX'],
    '2':['Cloud-to-Ground Lightning Flash Density','km-2 day-1','CDGDLTFD'],
    '3':['Cloud-to-Cloud Lightning Flash Density','km-2 day-1','CDCDLTFD'],
    '4':['Total Lightning Flash Density','km-2 day-1','TLGTFD'],
    '5-191':['Reserved','unknown','unknown'],
    '192-254':['Reserved for Local Use','unknown','unknown'],
    '192':['Lightning','non-dim','LTNG'],
    '255':['Missing','unknown','unknown'],
    }
    table_4_2_0_18  = {
    '0':['Air Concentration of Caesium 137','Bq m-3','ACCES'],
    '1':['Air Concentration of Iodine 131','Bq m-3','ACIOD'],
    '2':['Air Concentration of Radioactive Pollutant','Bq m-3','ACRADP'],
    '3':['Ground Deposition of Caesium 137','Bq m-2','GDCES'],
    '4':['Ground Deposition of Iodine 131','Bq m-2','GDIOD'],
    '5':['Ground Deposition of Radioactive Pollutant','Bq m-2','GDRADP'],
    '6':['Time Integrated Air Concentration of Cesium Pollutant','Bq s m-3','TIACCP'],
    '7':['Time Integrated Air Concentration of Iodine Pollutant','Bq s m-3','TIACIP'],
    '8':['Time Integrated Air Concentration of Radioactive Pollutant','Bq s m-3','TIACRP'],
    '9':['Reserved','unknown','unknown'],
    '10':['Air Concentration','Bq m-3','AIRCON'],
    '11':['Wet Deposition','Bq m-2','WETDEP'],
    '12':['Dry Deposition','Bq m-2','DRYDEP'],
    '13':['Total Deposition (Wet + Dry)','Bq m-2','TOTLWD'],
    '14':['Specific Activity Concentration','Bq kg-1','SACON'],
    '15':['Maximum of Air Concentration in Layer','Bq m-3','MAXACON'],
    '16':['Height of Maximum of Air Concentration','m','HMXACON'],
    '17':['Column-Integrated Air Concentration','Bq m-2','CIAIRC'],
    '18':['Column-Averaged Air Concentration in Layer','Bq m-3','CAACL'],
    '19-191':['Reserved','unknown','unknown'],
    '192-254':['Reserved for Local Use','unknown','unknown'],
    '255':['Missing','unknown','unknown'],
    }
    table_4_2_0_19  = {
    '0':['Visibility','m','VIS'],
    '1':['Albedo','%','ALBDO'],
    '2':['Thunderstorm Probability','%','TSTM'],
    '3':['Mixed Layer Depth','m','MIXHT'],
    '4':['Volcanic Ash','See Table 4.206','VOLASH'],
    '5':['Icing Top','m','ICIT'],
    '6':['Icing Base','m','ICIB'],
    '7':['Icing','See Table 4.207','ICI'],
    '8':['Turbulence Top','m','TURBT'],
    '9':['Turbulence Base','m','TURBB'],
    '10':['Turbulence','See Table 4.208','TURB'],
    '11':['Turbulent Kinetic Energy','J kg-1','TKE'],
    '12':['Planetary Boundary Layer Regime','See Table 4.209','PBLREG'],
    '13':['Contrail Intensity','See Table 4.210','CONTI'],
    '14':['Contrail Engine Type','See Table 4.211','CONTET'],
    '15':['Contrail Top','m','CONTT'],
    '16':['Contrail Base','m','CONTB'],
    '17':['Maximum Snow Albedosee Note 1','%','MXSALB'],
    '18':['Snow-Free Albedo','%','SNFALB'],
    '19':['Snow Albedo','%','SALBD'],
    '20':['Icing','%','ICIP'],
    '21':['In-Cloud Turbulence','%','CTP'],
    '22':['Clear Air Turbulence (CAT)','%','CAT'],
    '23':['Supercooled Large Droplet  Probabilitysee Note 2','%','SLDP'],
    '24':['Convective Turbulent Kinetic Energy','J kg-1','CONTKE'],
    '25':['Weather','See Table 4.225','WIWW'],
    '26':['Convective Outlook','See Table 4.224','CONVO'],
    '27':['Icing Scenario','See Table 4.227','ICESC'],
    '28':['Mountain Wave Turbulence (Eddy Dissipation Rate)','m2/3 s-1','MWTURB'],
    '29':['Clear Air Turbulence (CAT) (Eddy Dissipation Rate)','m2/3 s-1','CATEDR'],
    '30':['Eddy Dissipation Parameter','m2/3 s-1','EDPARM'],
    '31':['Maximum of Eddy Dissipation Parameter in Layer','m2/3 s-1','MXEDPRM'],
    '32':['Highest Freezing Level','m','HIFREL'],
    '33':['Visibility Through Liquid Fog','m','VISLFOG'],
    '34':['Visibility Through Ice Fog','m','VISIFOG'],
    '35':['Visibility Through Blowing Snow','m','VISBSN'],
    '36':['Presence of Snow Squalls','See Table 4.222','PSNOWS'],
    '37':['Icing Severity','See Table 4.228','ICESEV'],
    '38-191':['Reserved','unknown','unknown'],
    '192-254':['Reserved for Local Use','unknown','unknown'],
    '192':['Maximum Snow Albedo','%','MXSALB'],
    '193':['Snow-Free Albedo','%','SNFALB'],
    '194':['Slight risk convective outlook','categorical','SRCONO'],
    '195':['Moderate risk convective outlook','categorical','MRCONO'],
    '196':['High risk convective outlook','categorical','HRCONO'],
    '197':['Tornado probability','%','TORPROB'],
    '198':['Hail probability','%','HAILPROB'],
    '199':['Wind probability','%','WINDPROB'],
    '200':['Significant Tornado probability','%','STORPROB'],
    '201':['Significant Hail probability','%','SHAILPRO'],
    '202':['Significant Wind probability','%','SWINDPRO'],
    '203':['Categorical Thunderstorm','Code table 4.222','TSTMC'],
    '204':['Number of mixed layers next to surface','integer','MIXLY'],
    '205':['Flight Category','unknown','FLGHT'],
    '206':['Confidence - Ceiling','unknown','CICEL'],
    '207':['Confidence - Visibility','unknown','CIVIS'],
    '208':['Confidence - Flight Category','unknown','CIFLT'],
    '209':['Low-Level aviation interest','unknown','LAVNI'],
    '210':['High-Level aviation interest','unknown','HAVNI'],
    '211':['Visible, Black Sky Albedo','%','SBSALB'],
    '212':['Visible, White Sky Albedo','%','SWSALB'],
    '213':['Near IR, Black Sky Albedo','%','NBSALB'],
    '214':['Near IR, White Sky Albedo','%','NWSALB'],
    '215':['Total Probability of Severe Thunderstorms (Days 2,3)','%','PRSVR'],
    '216':['Total Probability of Extreme Severe Thunderstorms (Days 2,3)','%','PRSIGSVR'],
    '217':['Supercooled Large Droplet (SLD) Icingsee Note 2','See Table 4.207','SIPD'],
    '218':['Radiative emissivity','unknown','EPSR'],
    '219':['Turbulence Potential Forecast Index','unknown','TPFI'],
    '220':['Categorical Severe Thunderstorm','Code table 4.222','SVRTS'],
    '221':['Probability of Convection','%','PROCON'],
    '222':['Convection Potential','Code table 4.222','CONVP'],
    '223-231':['Reserved','unknown','unknown'],
    '232':['Volcanic Ash Forecast Transport and Dispersion','log10 (kg m-3)','VAFTD'],
    '233':['Icing probability','non-dim','ICPRB'],
    '234':['Icing Severity','non-dim','ICSEV'],
    '235':['Joint Fire Weather Probability','%','JFWPRB'],
    '236':['Snow Level','m','SNOWLVL'],
    '237':['Dry Thunderstorm Probability','%','DRYTPROB'],
    '238':['Ellrod Index','unknown','ELLINX'],
    '239':['Craven-Wiedenfeld Aggregate Severe Parameter','Numeric','CWASP'],
    '255':['Missing','unknown','unknown'],
    }
    table_4_2_0_20  = {
    '0':['Mass Density (Concentration)','kg m-3','MASSDEN'],
    '1':['Column-Integrated Mass Density','kg m-2','COLMD'],
    '2':['Mass Mixing Ratio (Mass Fraction in Air)','kg kg-1','MASSMR'],
    '3':['Atmosphere Emission Mass Flux','kg m-2s-1','AEMFLX'],
    '4':['Atmosphere Net Production Mass Flux','kg m-2s-1','ANPMFLX'],
    '5':['Atmosphere Net Production And Emision Mass Flux','kg m-2s-1','ANPEMFLX'],
    '6':['Surface Dry Deposition Mass Flux','kg m-2s-1','SDDMFLX'],
    '7':['Surface Wet Deposition Mass Flux','kg m-2s-1','SWDMFLX'],
    '8':['Atmosphere Re-Emission Mass Flux','kg m-2s-1','AREMFLX'],
    '9':['Wet Deposition by Large-Scale Precipitation Mass Flux','kg m-2s-1','WLSMFLX'],
    '10':['Wet Deposition by Convective Precipitation Mass Flux','kg m-2s-1','WDCPMFLX'],
    '11':['Sedimentation Mass Flux','kg m-2s-1','SEDMFLX'],
    '12':['Dry Deposition Mass Flux','kg m-2s-1','DDMFLX'],
    '13':['Transfer From Hydrophobic to Hydrophilic','kg kg-1s-1','TRANHH'],
    '14':['Transfer From SO2 (Sulphur Dioxide) to SO4 (Sulphate)','kg kg-1s-1','TRSDS'],
    '15':['Dry deposition velocity','m s-1','DDVEL'],
    '16':['Mass mixing ratio with respect to dry air','kg kg-1','MSSRDRYA'],
    '17':['Mass mixing ratio with respect to wet air','kg kg-1','MSSRWETA'],
    '18-49':['Reserved','unknown','unknown'],
    '50':['Amount in Atmosphere','mol','AIA'],
    '51':['Concentration In Air','mol m-3','CONAIR'],
    '52':['Volume Mixing Ratio (Fraction in Air)','mol mol-1','VMXR'],
    '53':['Chemical Gross Production Rate of Concentration','mol m-3s-1','CGPRC'],
    '54':['Chemical Gross Destruction Rate of Concentration','mol m-3s-1','CGDRC'],
    '55':['Surface Flux','mol m-2s-1','SFLUX'],
    '56':['Changes Of Amount in Atmosphere','mol s-1','COAIA'],
    '57':['Total Yearly Average Burden of The Atmosphere>','mol','TYABA'],
    '58':['Total Yearly Average Atmospheric Loss','mol s-1','TYAAL'],
    '59':['Aerosol Number Concentration','m-3','ANCON'],
    '60':['Aerosol Specific Number Concentration','kg-1','ASNCON'],
    '61':['Maximum of Mass Density','kg m-3','MXMASSD'],
    '62':['Height of Mass Density','m','HGTMD'],
    '63':['Column-Averaged Mass Density in Layer','kg m-3','CAVEMDL'],
    '64':['Mole fraction with respect to dry air','mol mol-1','MOLRDRYA'],
    '65':['Mole fraction with respect to wet air','mol mol-1','MOLRWETA'],
    '66':['Column-integrated in-cloud scavenging rate by precipitation','kg m-2 s-1','CINCLDSP'],
    '67':['Column-integrated below-cloud scavenging rate by precipitation','kg m-2 s-1','CBLCLDSP'],
    '68':['Column-integrated release rate from evaporating precipitation','kg m-2 s-1','CIRELREP'],
    '69':['Column-integrated in-cloud scavenging rate by large-scale precipitation','kg m-2 s-1','CINCSLSP'],
    '70':['Column-integrated below-cloud scavenging rate by large-scale precipitation','kg m-2 s-1','CBECSLSP'],
    '71':['Column-integrated release rate from evaporating large-scale precipitation','kg m-2 s-1','CRERELSP'],
    '72':['Column-integrated in-cloud scavenging rate by convective precipitation','kg m-2 s-1','CINCSRCP'],
    '73':['Column-integrated below-cloud scavenging rate by convective precipitation','kg m-2 s-1','CBLCSRCP'],
    '74':['Column-integrated release rate from evaporating convective precipitation','kg m-2 s-1','CIRERECP'],
    '75':['Wildfire flux','kg m-2 s-1','WFIREFLX'],
    '76':['Emission Rate','kg kg-1 s-1','EMISFLX'],
    '77':['Surface Emission flux','kg m-2 s-1','SFCEFLX'],
    '78-99':['Reserved','unknown','unknown'],
    '100':['Surface Area Density (Aerosol)','m-1','SADEN'],
    '101':['Vertical Visual Range','m','ATMTK'],
    '102':['Aerosol Optical Thickness','Numeric','AOTK'],
    '103':['Single Scattering Albedo','Numeric','SSALBK'],
    '104':['Asymmetry Factor','Numeric','ASYSFK'],
    '105':['Aerosol Extinction Coefficient','m-1','AECOEF'],
    '106':['Aerosol Absorption Coefficient','m-1','AACOEF'],
    '107':['Aerosol Lidar Backscatter from Satellite','m-1sr-1','ALBSAT'],
    '108':['Aerosol Lidar Backscatter from the Ground','m-1sr-1','ALBGRD'],
    '109':['Aerosol Lidar Extinction from Satellite','m-1','ALESAT'],
    '110':['Aerosol Lidar Extinction from the Ground','m-1','ALEGRD'],
    '111':['Angstrom Exponent','Numeric','ANGSTEXP'],
    '112':['Scattering Aerosol Optical Thickness','Numeric','SCTAOTK'],
    '113-191':['Reserved','unknown','unknown'],
    '192-254':['Reserved for Local Use','unknown','unknown'],
    '255':['Missing','unknown','unknown'],
    }
    table_4_2_0_190  = {
    '0':['Arbitrary Text String','CCITTIA5','ATEXT'],
    '1-191':['Reserved','unknown','unknown'],
    '192-254':['Reserved for Local Use','unknown','unknown'],
    '255':['Missing','unknown','unknown'],
    }
    table_4_2_0_191  = {
    '0':['Seconds prior to initial reference time (defined in Section 1)','s','TSEC'],
    '1':['Geographical Latitude','° N','GEOLAT'],
    '2':['Geographical Longitude','° E','GEOLON'],
    '3':['Days Since Last Observation','d','DSLOBS'],
    '4-191':['Reserved','unknown','unknown'],
    '192-254':['Reserved for Local Use','unknown','unknown'],
    '192':['Latitude (-90 to 90)','°','NLAT'],
    '193':['East Longitude (0 to 360)','°','ELON'],
    '194':['Seconds prior to initial reference time','s','RTSEC'],
    '195':['Model Layer number (From bottom up)','unknown','MLYNO'],
    '196':['Latitude (nearest neighbor) (-90 to 90)','°','NLATN'],
    '197':['East Longitude (nearest neighbor) (0 to 360)','°','ELONN'],
    '255':['Missing','unknown','unknown'],
    }
    table_4_2_0_192  = {
    '1':['Covariance between zonal and meridional components of  the wind. Defined as [uv]-[u][v], where "[]" indicates the mean over the indicated time span.','m2/s2','COVMZ'],
    '2':['Covariance between zonal component of the wind and temperature.  Defined as [uT]-[u][T], where "[]" indicates the mean over the indicated time span.','K*m/s','COVTZ'],
    '3':['Covariance between meridional component of the wind and temperature.  Defined as [vT]-[v][T], where "[]" indicates the mean over the indicated time span.','K*m/s','COVTM'],
    '4':['Covariance between temperature and vertical component of  the wind. Defined as [wT]-[w][T], where "[]" indicates the mean over the indicated time span.','K*m/s','COVTW'],
    '5':['Covariance between zonal and zonal  components of the wind. Defined as [uu]-[u][u], where "[]" indicates  the mean over the indicated time span.','m2/s2','COVZZ'],
    '6':['Covariance between meridional and meridional  components of the wind. Defined as [vv]-[v][v], where "[]" indicates  the mean over the indicated time span.','m2/s2','COVMM'],
    '7':['Covariance between specific humidity and zonal  components of the wind. Defined as [uq]-[u][q], where "[]" indicates  the mean over the indicated time span.','kg/kg*m/s','COVQZ'],
    '8':['Covariance between specific humidity and meridional  components of the wind. Defined as [vq]-[v][q], where "[]" indicates  the mean over the indicated time span.','kg/kg*m/s','COVQM'],
    '9':['Covariance between temperature and vertical  components of the wind. Defined as [ΩT]-[Ω][T], where "[]" indicates  the mean over the indicated time span.','K*Pa/s','COVTVV'],
    '10':['Covariance between specific humidity and vertical  components of the wind. Defined as [Ωq]-[Ω][q], where "[]" indicates  the mean over the indicated time span.','kg/kg*Pa/s','COVQVV'],
    '11':['Covariance between surface pressure and surface pressure.  Defined as [Psfc]-[Psfc][Psfc], where "[]" indicates the mean over the indicated time span.','Pa*Pa','COVPSPS'],
    '12':['Covariance between specific humidity and specific  humidy. Defined as [qq]-[q][q], where "[]" indicates the mean over the indicated time span.','kg/kg*kg/kg','COVQQ'],
    '13':['Covariance between vertical and vertical  components of the wind. Defined as [ΩΩ]-[Ω][Ω], where "[]" indicates  the mean over the indicated time span.','Pa2/s2','COVVVVV'],
    '14':['Covariance between temperature and temperature.  Defined as [TT]-[T][T], where "[]" indicates the mean over the indicated time span.','K*K','COVTT'],
    '255':['Missing','unknown','unknown'],
    }